# tinder

[![Build Status](https://travis-ci.org/elbaro/tinder.svg?branch=master)](https://travis-ci.org/elbaro/tinder) [![Code Coverage](https://codecov.io/gh/elbaro/tinder/branch/master/graph/badge.svg)](https://codecov.io/gh/elbaro/tinder)


[![Docs Link](https://img.shields.io/badge/docs-master-orange.svg)](https://elbaro.github.io/tinder)

Pytorch library.

See [Documentation](https://elbaro.github.io/tinder)

## Usage

```
pip install tinder
```

```py
import tinder

tinder.nn
tinder.image
tinder.config
tinder.optimizer
tinder.saver
tinder.visualize
tinder.metrics
tinder.dataset
tinder.monitor
tinder.queue
tinder.rl
tinder.model
```
